@@ -15,12 +15,13 @@ from emora._flows.vacations import df as vacations
 from emora._flows.teleportation import teleportation
 from emora._flows.movies_return import movies_return
 from emora._flows.pets_return import component as pets_return
+from emora._flows.coronavirus_final import coronavirus_final
 
 from _globals import PATHDIR
 from emora_stdm import CompositeDialogueFlow,DialogueFlow,Macro
 from emora_stdm.state_transition_dialogue_manager.macros_common import _term_op_term
 import emora_stdm
-from emora._flows._global_nlu import personal_nlu, global_update_rules
+from emora._flows._global_nlu import personal_nlu, global_update_rules, contraction_rule
 from emora._flows._macros import macros
 from emora._flows._central_knowledge import central_knowledge
 
@@ -40,7 +41,8 @@ flow_components = {
     'teleportation': teleportation,
     'hobby': hobby,
     'movies_return': movies_return,
-    'pets_return': pets_return
+    'pets_return': pets_return,
+    'cv_final': coronavirus_final
 }
 
 cdf = CompositeDialogueFlow('root', 'recovery_from_failure', 'recovery_from_failure',
@@ -53,16 +55,16 @@ for namespace, component in flow_components.items():
 
 cdf.add_system_transition('root', 'house:start', '')
 
-cdf.add_system_transition('root', 'worklife:start', '')
+cdf.add_system_transition('root', 'worklife:start', '`You know, you seem like a pretty interesting person. `')
 cdf.add_system_transition('root', 'worklife:start->worklife:remember_is_employed_open', '', score=9.0)
 cdf.add_system_transition('root', 'worklife:start->worklife:like_job_answer', '', score=10.0)
 
-cdf.add_system_transition('root', 'school_new:start', '')
-cdf.add_system_transition('root', 'sibling:start', '')
+cdf.add_system_transition('root', 'school_new:start', '`Hey by the way, `')
+cdf.add_system_transition('root', 'sibling:start', '`You know, I can\'t put my finger on why, but you kind of seem like you have a sister.`')
 
 cdf.add_system_transition('root', 'relationships:dating', '')
 cdf.add_system_transition('root', 'relationships:dating->relationships:relationship_length', '', score=10.0)
-cdf.add_system_transition('root', 'relationships:marriage', '',score=100)
+cdf.add_system_transition('root', 'relationships:marriage', '')
 cdf.add_system_transition('root', 'relationships:marriage->relationships:how_long_married', '', score=10.0)
 
 cdf.add_system_transition('root', 'baby:start', '')
@@ -71,6 +73,8 @@ cdf.add_system_transition('root', 'baby:start->baby:asked_kids_age', '', score=1
 cdf.add_system_transition('root', 'hobby:start', '')
 cdf.add_system_transition('root', 'hobby:today_flow', '')
 
+cdf.add_system_transition('root', 'cv_final:start', '')
+
 cdf.add_system_transition('root', 'movies_return:start', '', score=15.0)
 cdf.add_system_transition('root', 'pets_return:start', '', score=15.0)
 cdf.add_system_transition('root', 'baby:returning', '', score=15.0)
@@ -96,6 +100,7 @@ class Known(Macro):
 central_kb = cdf.component('SYSTEM').knowledge_base()
 for component in cdf.components():
     component.load_update_rules(global_update_rules, score=999999999)
+    component.load_update_rules(contraction_rule, score=999999999999)
     component.load_global_nlu(personal_nlu, 5.0)
     component.add_macros({'CNC': emora_stdm.CheckNotComponent(cdf), "KNOWN": Known()})
     component.add_macros(macros)
